netapp_ontap.models.mediator_ping_error API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.mediator_ping_error`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class MediatorPingErrorSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the MediatorPingError object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `configurable: bool GET`

    Indicates if the BlueXP cloud mediator is configurable. This depends on whether the ping latency is within a threshold.

    Example: false

  `error: MediatorPingErrorError GET POST PATCH`

    The error field of the mediator_ping_error.

  `reachable: bool GET`

    Ping status of the BlueXP cloud service.

    Example: false